@@ -1,25 +1,30 @@
-
 context("cleaning the records")
 
 # shorter delay to speed tests
 old_delay <- getOption("aRxiv_delay")
 options(aRxiv_delay=0.5)
 
-# count papers on 1997-01-01
-query <- "lastUpdatedDate:[199701010000 TO 199701012400]"
-# ignore search_info attribute and class
-expect_equal(omit_attr(arxiv_count(query)), 20)
+# do this only if not on CRAN
+on_cran <- Sys.getenv("NOT_CRAN")!="true"
+if(!on_cran) {
+    # count papers on 1997-01-01
+    query <- "lastUpdatedDate:[199701010000 TO 199701012400]"
 
-# do raw search to test parsing
-library(httr)
-query_url <- "http://export.arxiv.org/api/query"
-delay_if_necessary()
-z <- POST(query_url, body=list(search_query=query,
-                               start=0, max_results=20,
-                               sort_by="submitted"))
-z <- get_entries(result2list(z))
+    # ignore search_info attribute and class
+    expect_equal(omit_attr(arxiv_count(query)), 20)
+
+    # do raw search to test parsing
+    query_url <- "http://export.arxiv.org/api/query"
+    delay_if_necessary()
+
+    z <- httr::POST(query_url, body=list(search_query=query,
+                                         start=0, max_results=20,
+                                         sort_by="submitted"))
+    z <- get_entries(result2list(z))
+}
 
 test_that("clean_authors works right", {
+    skip_on_cran()
 
     cleaned_auth <- clean_authors(z[[1]])
     expected_result <- list(names="J. Michael Owen|Jens V. Villumsen",
@@ -38,6 +43,7 @@ test_that("clean_authors works right", {
 })
 
 test_that("clean_links works right", {
+    skip_on_cran()
 
     cleaned_links <- clean_links(z[[1]])
     expected_result <- list(link_abstract="http://arxiv.org/abs/astro-ph/9603156v3",
@@ -68,6 +74,7 @@ test_that("clean_links works right", {
 
 
 test_that("clean_categories works right", {
+    skip_on_cran()
 
     cleaned_categories <- clean_categories(z[[1]])
     expected_result <- "astro-ph"
@@ -90,6 +97,7 @@ test_that("clean_categories works right", {
 })
 
 test_that("clean_record works right", {
+    skip_on_cran()
 
     clean_record <- clean_record(z[[1]])
     expected_result <- c(id="astro-ph/9603156v3",
@@ -155,6 +163,7 @@ test_that("clean_record works right", {
 })
 
 test_that("listresult2df works right", {
+    skip_on_cran()
 
     zdf <- listresult2df(z)
 
